@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use parent 'Alien::Base';
  
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 NAME
 
@@ -36,6 +36,22 @@ operating system, and it can be found, this distribution will use the Doxyparse
 that comes with your operating system, otherwise it will download it from the
 Internet, build and install it from you.
 
+=head1 DOXYPARSE VERSION
+
+Every release of this package installs a stable version of Doxyparse, normally
+the latest Doxyparse release. But, it's possible to specify an arbitrary
+Doxyparse version by setting C<ALIEN_DOXYPARSE_VERSION> variable.
+
+Example installing Doxyparse C<1.8.14-6> version:
+
+    ALIEN_DOXYPARSE_VERSION=1.8.14-6 cpan -i Alien::Doxyparse
+
+See all the
+L<Doxyparse releases on Github|https://github.com/analizo/doxyparse/releases>.
+To install Doxyparse from master branch use C<master> as version:
+
+    ALIEN_DOXYPARSE_VERSION=master cpan -i Alien::Doxyparse
+
 =head1 SEE ALSO
 
 =over
